pub struct ThrottledErrorLogger {
pub suppressed_errors: HashMap<String, usize>,
/* private fields */
}Expand description
If metrics cannot be reported for extended periods of time, logging new metrics will fail and the error messages tend to clutter up the logs. This container limits the rate at which such potentially noisy logs are reported. Duplicate error messages are aggregated periodically reported.
Fields
suppressed_errors: HashMap<String, usize>Implementations